==> moodle-1.4.3-pgsql.tgz: moodle/lang/ru/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.4 development (2004080300)


$string['addresource'] = ' ';
$string['chooseafile'] = '   ';
$string['chooseparameter'] = ' ';
$string['configdefaulturl'] = '      URL ,       URL.';
$string['configfilterexternalpages'] = '     (-,  HTML )     (      ).             -        .';
$string['configframesize'] = '  web-     ,     ( )   (  ).';
$string['configpopup'] = '   ,       (popup) ,     ?';
$string['configpopupdirectories'] = ' (popup)       ?';
$string['configpopupheight'] = '        (popup) ?';
$string['configpopuplocation'] = '      (popup)   ?';
$string['configpopupmenubar'] = '     (popup)   ?';
$string['configpopupresizable'] = '     (popup)   ?';
$string['configpopupscrollbars'] = '     (popup)   ?';
$string['configpopupstatus'] = '      (popup)   ?';
$string['configpopuptoolbar'] = '         (popup) ?';
$string['configpopupwidth'] = '         (popup) ?';
$string['configwebsearch'] = '  URL  webpage  weblink,     ,     URL.';
$string['directlink'] = '    ';
$string['directoryinfo'] = '      .';
$string['display'] = '';
$string['editingaresource'] = ' ';
$string['encryptedcode'] = ' ';
$string['example'] = '';
$string['exampleurl'] = 'http://www.example.com/somedirectory/somefile.html';
$string['fetchclienterror'] = '      -       -   (  URL).';
$string['fetcherror'] = '       - .';
$string['fetchservererror'] = '          -  (  ). </p>';
$string['filename'] = ' ';
$string['filtername'] = ' -  ';
$string['frameifpossible'] = '        ';
$string['fulltext'] = ' ';
$string['htmlfragment'] = 'HTML-';
$string['maindirectory'] = '  ';
$string['modulename'] = '';
$string['modulenameplural'] = '';
$string['neverseen'] = '  ';
$string['newdirectories'] = '    ';
$string['newfullscreen'] = '  ';
$string['newheight'] = '  ( )  ';
$string['newlocation'] = '  ';
$string['newmenubar'] = ' ';
$string['newresizable'] = '   ';
$string['newscrollbars'] = '  ';
$string['newstatus'] = ' c ';
$string['newtoolbar'] = '  ';
$string['newwidth'] = '  ( )  ';
$string['newwindow'] = ' ';
$string['newwindowopen'] = '    (popup) ';
$string['note'] = '';
$string['notefile'] = '       <A HREF=$a >-</A>.';
$string['notypechosen'] = '  .     .';
$string['pagedisplay'] = '     ';
$string['pagewindow'] = ' ';
$string['parameter'] = '';
$string['parameters'] = '';
$string['popupresource'] = '      (popup) .';
$string['popupresourcelink'] = '   ,  : $a';
$string['resourcetype'] = ' ';
$string['resourcetype1'] = '';
$string['resourcetype2'] = 'Web-';
$string['resourcetype3'] = '';
$string['resourcetype4'] = '';
$string['resourcetype5'] = 'Web-';
$string['resourcetype6'] = 'HTML-';
$string['resourcetype7'] = '';
$string['resourcetype8'] = 'WIKI-';
$string['resourcetype9'] = '';
$string['resourcetypedirectory'] = ' ';
$string['resourcetypefile'] = '    -';
$string['resourcetypehtml'] = ' -';
$string['resourcetypelabel'] = ' ';
$string['resourcetypetext'] = '  ';
$string['searchweb'] = ' -';
$string['variablename'] = ' ';

?>

==> moodle-1.5-pgsql.tgz: moodle/lang/ru/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.4.5 (2004083150)


$string['addresource'] = ' ';
$string['chooseafile'] = '   ';
$string['chooseparameter'] = ' ';
$string['configdefaulturl'] = '      URL ,       URL.';
$string['configfilterexternalpages'] = '     (-,  HTML )      (      ).     ,        -        .';
$string['configframesize'] = '  web-     ,     ( )   (  ).';
$string['configpopup'] = '   ,       (popup) ,     ?';
$string['configpopupdirectories'] = ' (popup)       ?';
$string['configpopupheight'] = '        (popup) ?';
$string['configpopuplocation'] = '       (popup)   ?';
$string['configpopupmenubar'] = '      (popup)   ?';
$string['configpopupresizable'] = '     (popup)   ?';
$string['configpopupscrollbars'] = '      (popup)   ?';
$string['configpopupstatus'] = '       (popup)   ?';
$string['configpopuptoolbar'] = '         (popup) ?';
$string['configpopupwidth'] = '         (popup) ?';
$string['configwebsearch'] = '  URL  webpage  weblink,     ,     URL.';
$string['directlink'] = '    ';
$string['directoryinfo'] = '      .';
$string['display'] = '';
$string['editingaresource'] = ' ';
$string['encryptedcode'] = ' ';
$string['example'] = '';
$string['exampleurl'] = 'http://www.example.com/somedirectory/somefile.html';
$string['fetchclienterror'] = '     -     -  (,  URL).';
$string['fetcherror'] = '       - .';
$string['fetchservererror'] = '         - (  ).';
$string['filename'] = ' ';
$string['filtername'] = '- ';
$string['frameifpossible'] = '   ,     .';
$string['fulltext'] = ' ';
$string['htmlfragment'] = 'HTML-';
$string['maindirectory'] = '  ';
$string['modulename'] = '';
$string['modulenameplural'] = '';
$string['neverseen'] = '  ';
$string['newdirectories'] = '    ';
$string['newfullscreen'] = '  ';
$string['newheight'] = '  ( )  ';
$string['newlocation'] = ' ';
$string['newmenubar'] = ' ';
$string['newresizable'] = '   ';
$string['newscrollbars'] = '  ';
$string['newstatus'] = ' c ';
$string['newtoolbar'] = '  ';
$string['newwidth'] = '  ( )  ';
$string['newwindow'] = ' ';
$string['newwindowopen'] = '    (popup) ';
$string['note'] = '';
$string['notefile'] = '       <a href=\"$a\">-</a>.';
$string['notypechosen'] = '  .     .';
$string['pagedisplay'] = '     ';
$string['pagewindow'] = '  ';
$string['parameter'] = '';
$string['parameters'] = '';
$string['popupresource'] = '      (popup) .';
$string['popupresourcelink'] = '   ,  : $a';
$string['resourcetype'] = ' ';
$string['resourcetype1'] = '';
$string['resourcetype2'] = 'Web-';
$string['resourcetype3'] = '';
$string['resourcetype4'] = '';
$string['resourcetype5'] = 'Web-';
$string['resourcetype6'] = 'HTML-';
$string['resourcetype7'] = '';
$string['resourcetype8'] = 'WIKI-';
$string['resourcetype9'] = '';
$string['resourcetypedirectory'] = '  ';
$string['resourcetypefile'] = '    -';
$string['resourcetypehtml'] = '-';
$string['resourcetypelabel'] = '';
$string['resourcetypetext'] = ' ';
$string['searchweb'] = ' -';
$string['variablename'] = ' ';

?>
